@@ -2,7 +2,7 @@
 #
 #       clipboard.py
 #
-#       Copyright 2009-2016 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2017 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -19,8 +19,17 @@
 #       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 #       MA 02110-1301, USA.
 
-import gtk, os, xml.dom.minidom, re, base64, mimetypes
-import cons, machines, exports, imports, support
+import gtk
+import os
+import xml.dom.minidom
+import re
+import base64
+import mimetypes
+import cons
+import machines
+import exports
+import imports
+import support
 
 
 TARGET_CTD_PLAIN_TEXT = 'UTF8_STRING'
@@ -311,7 +320,7 @@ class ClipboardHandler:
                     iter_sel_end = self.dad.curr_buffer.get_iter_at_offset(start_offset + len(element))
                     self.dad.curr_buffer.apply_tag_by_name(self.dad.apply_tag_exist_or_create(cons.TAG_LINK, property_value),
                                                            iter_sel_start, iter_sel_end)
-        self.dad.sourceview.scroll_to_mark(self.dad.curr_buffer.get_insert(), cons.SCROLL_MARGIN)
+        self.dad.sourceview.scroll_mark_onscreen(self.dad.curr_buffer.get_insert())
 
     def to_html(self, clipboard, selectiondata, data):
         """From Clipboard to HTML Text"""
@@ -326,7 +335,7 @@ class ClipboardHandler:
         html_import = imports.HTMLHandler(self.dad)
         xml_string = html_import.get_clipboard_selection_xml(selection_data)
         self.from_xml_string_to_buffer(xml_string)
-        self.dad.sourceview.scroll_to_mark(self.dad.curr_buffer.get_insert(), cons.SCROLL_MARGIN)
+        self.dad.sourceview.scroll_mark_onscreen(self.dad.curr_buffer.get_insert())
 
     def to_plain_text(self, clipboard, selectiondata, data):
         """From Clipboard to Plain Text"""
@@ -363,7 +372,7 @@ class ClipboardHandler:
                         self.dad.curr_buffer.apply_tag_by_name(self.dad.apply_tag_exist_or_create(cons.TAG_LINK, property_value),
                                                                iter_sel_start, iter_sel_end)
         self.force_plain_text = False
-        self.dad.sourceview.scroll_to_mark(self.dad.curr_buffer.get_insert(), cons.SCROLL_MARGIN)
+        self.dad.sourceview.scroll_mark_onscreen(self.dad.curr_buffer.get_insert())
 
     def to_rich_text(self, clipboard, selectiondata, data):
         """From Clipboard to Rich Text"""
@@ -372,7 +381,7 @@ class ClipboardHandler:
             print "? no clipboard rich text"
             return
         self.from_xml_string_to_buffer(rich_text)
-        self.dad.sourceview.scroll_to_mark(self.dad.curr_buffer.get_insert(), cons.SCROLL_MARGIN)
+        self.dad.sourceview.scroll_mark_onscreen(self.dad.curr_buffer.get_insert())
 
     def from_xml_string_to_buffer(self, xml_string):
         """From XML String to Text Buffer"""
@@ -381,6 +390,7 @@ class ClipboardHandler:
         if dom_node.nodeName != "root":
             print "rich text from clipboard error"
             return
+        self.dad.state_machine.not_undoable_timeslot_set(True)
         child_dom_iter = dom_node.firstChild
         while child_dom_iter != None:
             if child_dom_iter.nodeName == "slot":
@@ -396,6 +406,7 @@ class ClipboardHandler:
                         self.dom_node_to_codebox(nephew_dom_iter)
                     nephew_dom_iter = nephew_dom_iter.nextSibling
             child_dom_iter = child_dom_iter.nextSibling
+        self.dad.state_machine.not_undoable_timeslot_set(False)
 
     def dom_node_to_rich_text(self, dom_node):
         """From dom_node to Rich Text"""
@@ -420,7 +431,7 @@ class ClipboardHandler:
         pixbuf = selectiondata.get_pixbuf()
         pixbuf.link = ""
         self.dad.image_insert(self.dad.curr_buffer.get_iter_at_mark(self.dad.curr_buffer.get_insert()), pixbuf)
-        self.dad.sourceview.scroll_to_mark(self.dad.curr_buffer.get_insert(), cons.SCROLL_MARGIN)
+        self.dad.sourceview.scroll_mark_onscreen(self.dad.curr_buffer.get_insert())
 
     def dom_node_to_image(self, dom_node):
         """From dom_node to Image"""
@@ -454,7 +465,7 @@ class ClipboardHandler:
             print "codebox from clipboard error"
             return
         self.dom_node_to_codebox(dom_node)
-        self.dad.sourceview.scroll_to_mark(self.dad.curr_buffer.get_insert(), cons.SCROLL_MARGIN)
+        self.dad.sourceview.scroll_mark_onscreen(self.dad.curr_buffer.get_insert())
 
     def dom_node_to_codebox(self, dom_node):
         """From dom_node to CodeBox"""
@@ -485,7 +496,7 @@ class ClipboardHandler:
             print "table from clipboard error"
             return
         self.dom_node_to_table(dom_node, table_model_n_iter)
-        self.dad.sourceview.scroll_to_mark(self.dad.curr_buffer.get_insert(), cons.SCROLL_MARGIN)
+        self.dad.sourceview.scroll_mark_onscreen(self.dad.curr_buffer.get_insert())
 
     def dom_node_to_table(self, dom_node, table_model_n_iter):
         """From dom_node to Table"""
