@@ -62,7 +62,7 @@ def auto_decode_str(in_str, from_clipboard=False):
     elif in_str.startswith(("\xFF\xFE", "\xFE\xFF")): # UTF-16 BOMs
         encodings += [cons.STR_UTF16]
     elif from_clipboard:
-        if "html" in in_str or "HTML" in in_str:
+        if re.search(r"</[a-zA-Z]+>", in_str) is not None:
             encodings = [cons.STR_UTF8] + encodings
         else:
             encodings = [cons.STR_UTF16, cons.STR_UTF8] + encodings
@@ -271,9 +271,9 @@ def on_sourceview_event_after_scroll(dad, text_view, event):
     """Called after every gtk.gdk.SCROLL on the SourceView"""
     if dad.ctrl_down:
         if event.direction == gtk.gdk.SCROLL_UP:
-            dad.zoom_text_p()
+            dad.zoom_text(True)
         elif event.direction == gtk.gdk.SCROLL_DOWN:
-            dad.zoom_text_m()
+            dad.zoom_text(False)
     return False
 
 def on_sourceview_event_after_key_release(dad, text_view, event):
@@ -503,13 +503,14 @@ def sourceview_cursor_and_tooltips_handler(dad, text_view, x, y):
         text_view.get_window(gtk.TEXT_WINDOW_TEXT).set_cursor(gtk.gdk.Cursor(gtk.gdk.XTERM))
         text_view.set_tooltip_text(None)
 
-def rich_text_node_modify_codeboxes_font(start_iter, code_font):
+def rich_text_node_modify_codeboxes_font(start_iter, dad):
     """Modify Font to CodeBoxes"""
     curr_iter = start_iter.copy()
     while 1:
         anchor = curr_iter.get_child_anchor()
         if anchor and "sourcebuffer" in dir(anchor):
-            anchor.sourceview.modify_font(pango.FontDescription(code_font))
+            target_font = dad.code_font if anchor.syntax_highlighting != cons.PLAIN_TEXT_ID else dad.pt_font
+            anchor.sourceview.modify_font(pango.FontDescription(target_font))
         if not curr_iter.forward_char(): break
 
 def rich_text_node_modify_codeboxes_color(start_iter, dad):
@@ -557,17 +558,20 @@ def clean_from_chars_not_for_filename(filename_in):
     filename_out = filename_out.replace(cons.CHAR_NEWLINE, "").replace(cons.CHAR_CR, "").strip()
     return filename_out.replace(cons.CHAR_SPACE, cons.CHAR_USCORE)
 
-def get_node_hierarchical_name(dad, tree_iter, separator="--", for_filename=True, root_to_leaf=True):
+def get_node_hierarchical_name(dad, tree_iter, separator="--", for_filename=True, root_to_leaf=True, trailer=""):
     """Get the Node Hierarchical Name"""
-    hierarchical_name = dad.treestore[tree_iter][1].strip()
+    hierarchical_name = exports.clean_text_to_utf8(dad.treestore[tree_iter][1]).strip()
     father_iter = dad.treestore.iter_parent(tree_iter)
     while father_iter:
-        if root_to_leaf:
-            hierarchical_name = dad.treestore[father_iter][1].strip() + separator + hierarchical_name
+        father_name = exports.clean_text_to_utf8(dad.treestore[father_iter][1]).strip()
+        if root_to_leaf is True:
+            hierarchical_name = father_name + separator + hierarchical_name
         else:
-            hierarchical_name = hierarchical_name + separator + dad.treestore[father_iter][1].strip()
+            hierarchical_name = hierarchical_name + separator + father_name
         father_iter = dad.treestore.iter_parent(father_iter)
-    if for_filename:
+    if trailer:
+        hierarchical_name += trailer
+    if for_filename is True:
         hierarchical_name = clean_from_chars_not_for_filename(hierarchical_name)
         if len(hierarchical_name) > cons.MAX_FILE_NAME_LEN:
             hierarchical_name = hierarchical_name[-cons.MAX_FILE_NAME_LEN:]
@@ -861,6 +865,7 @@ MA 02110-1301, USA.
 _("Chinese Simplified")+" (zh_CN) Channing Wong <channing.wong@qq.com>"+cons.CHAR_NEWLINE+
 _("Czech")+" (cs) Pavel Fric <fripohled@blogspot.com>"+cons.CHAR_NEWLINE+
 _("Dutch")+" (nl) Luuk Geurts, Patrick Vijgeboom <pj.vijgeboom@gmail.com>"+cons.CHAR_NEWLINE+
+_("Finnish")+" (fi) Henri Kaustinen <hendrix.ks81@gmail.com>"+cons.CHAR_NEWLINE+
 _("French")+" (fr) Klaus Becker <colonius@free.fr>"+cons.CHAR_NEWLINE+
 _("German")+" (de) Frank Brungräber <calexu@arcor.de>"+cons.CHAR_NEWLINE+
 _("Greek")+" (el) Delphina <delphina.2009@yahoo.gr>"+cons.CHAR_NEWLINE+
@@ -1829,7 +1834,7 @@ def add_recent_document(dad, filepath):
 
 def insert_special_char(menu_item, special_char, dad):
     """A Special character insert was Requested"""
-    text_view, text_buffer, from_codebox = dad.get_text_view_n_buffer_codebox_proof()
+    text_view, text_buffer, syntax_highl, from_codebox = dad.get_text_view_n_buffer_codebox_proof()
     if not text_buffer: return
     if not dad.is_curr_node_not_read_only_or_error(): return
     text_buffer.insert_at_cursor(special_char)
